@@ -74,7 +74,7 @@ value_mappings = {
         WARM_WATER: "u6182-41",
     },
     "00.01.03.19": {
-        PV_POWER : "productionValue",
+        PV_POWER : "hidProduction",
         CAR_CHARGER_POWER : "carChargerPower",
         POWER : "detailsPowerValue",
         EFFECTIVE_POWER: None,
